@@ -22,7 +22,7 @@ from typing import List, Dict, Any, Tuple
 
 class Area:
     def __init__(self, /, **kwargs) -> object:
-        self.id: int = int(kwargs.get("id", 0))
+        self.id: str = kwargs.get("id", "")
         self.name: str = kwargs.get("name", "")
         self.municipality: str = kwargs.get("municipality", "")
         self.province: Province = Province(kwargs.get("province", 0))
@@ -154,8 +154,15 @@ class ProviderError(Exception):
 
 
 class Provider(abc.ABC):
+    ESKOM = 1
+    COCT = 2
+    SE_PUSH = 3
+
     name: str = "Provider"
 
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
     @abc.abstractmethod
     def get_areas(self, search_text: str = None, max_results: int = None) -> List[Area]:
         raise NotImplemented
@@ -166,3 +173,6 @@ class Provider(abc.ABC):
 
     def get_stage(self) -> Stage:
         pass
+
+    def get_stages(self) -> Dict:
+        pass
